@@ -1,9 +1,7 @@
 #ifndef CRYPTOPP_CAMELLIA_H
 #define CRYPTOPP_CAMELLIA_H
 
-#include "cryptopp_config.h"
-
-#ifdef WORD64_AVAILABLE
+#include "config.h"
 
 /** \file
 */
@@ -25,20 +23,16 @@ class Camellia : public Camellia_Info, public BlockCipherDocumentation
 	class CRYPTOPP_NO_VTABLE Base : public BlockCipherImpl<Camellia_Info>
 	{
 	public:
-		void UncheckedSetKey(CipherDir dir, const byte *key, unsigned int keylen);
+		void UncheckedSetKey(const byte *key, unsigned int keylen, const NameValuePairs &params);
 		void ProcessAndXorBlock(const byte *inBlock, const byte *xorBlock, byte *outBlock) const;
+		unsigned int BlockAlignment() const {return 8;}
 
 	protected:
-		static word64 F(word64 X);
-		static void FLlayer(word64 *x, word64 K1, word64 K2);
-
 		static const byte s1[256];
-		static const byte s2[256];
-		static const byte s3[256];
-		static const byte s4[256];
+		static const word32 SP[4][256];
 
 		unsigned int m_rounds;
-		SecBlock<word64> m_key;
+		SecBlock<word32> m_key;
 	};
 
 public:
@@ -52,5 +46,3 @@ typedef Camellia::Decryption CamelliaDecryption;
 NAMESPACE_END
 
 #endif
-
-#endif
