@@ -1,30 +1,43 @@
 #ifndef CRYPTOPP_HRTIMER_H
 #define CRYPTOPP_HRTIMER_H
 
-#include "cryptopp_config.h"
+#include "config.h"
+#ifndef HIGHRES_TIMER_AVAILABLE
+#include <time.h>
+#endif
 
 NAMESPACE_BEGIN(CryptoPP)
 
+#ifdef HIGHRES_TIMER_AVAILABLE
+	#ifdef WORD64_AVAILABLE
+		typedef word64 TimerWord;
+	#else
+		typedef word32 TimerWord;
+	#endif
+#else
+	typedef clock_t TimerWord;
+#endif
+
 //! _
-class TimerBase
+class CRYPTOPP_DLL CRYPTOPP_NO_VTABLE TimerBase
 {
 public:
 	enum Unit {SECONDS = 0, MILLISECONDS, MICROSECONDS, NANOSECONDS};
 	TimerBase(Unit unit, bool stuckAtZero)	: m_timerUnit(unit), m_stuckAtZero(stuckAtZero), m_started(false) {}
 
-	virtual word64 GetCurrentTimerValue() =0;	// GetCurrentTime is a macro in MSVC 6.0
-	virtual word64 TicksPerSecond() =0;	// this is not the resolution, just a conversion factor into seconds
+	virtual TimerWord GetCurrentTimerValue() =0;	// GetCurrentTime is a macro in MSVC 6.0
+	virtual TimerWord TicksPerSecond() =0;	// this is not the resolution, just a conversion factor into seconds
 
 	void StartTimer();
 	double ElapsedTimeAsDouble();
 	unsigned long ElapsedTime();
 
 private:
-	double ConvertTo(word64 t, Unit unit);
+	double ConvertTo(TimerWord t, Unit unit);
 
 	Unit m_timerUnit;	// HPUX workaround: m_unit is a system macro on HPUX
 	bool m_stuckAtZero, m_started;
-	word64 m_start;
+	TimerWord m_start, m_last;
 };
 
 //! measure CPU time spent executing instructions of this thread (if supported by OS)
@@ -34,23 +47,19 @@ class ThreadUserTimer : public TimerBase
 {
 public:
 	ThreadUserTimer(Unit unit = TimerBase::SECONDS, bool stuckAtZero = false)	: TimerBase(unit, stuckAtZero) {}
-	word64 GetCurrentTimerValue();
-	word64 TicksPerSecond();
+	TimerWord GetCurrentTimerValue();
+	TimerWord TicksPerSecond();
 };
 
-#ifdef HIGHRES_TIMER_AVAILABLE
-
 //! high resolution timer
-class Timer : public TimerBase
+class CRYPTOPP_DLL Timer : public TimerBase
 {
 public:
 	Timer(Unit unit = TimerBase::SECONDS, bool stuckAtZero = false)	: TimerBase(unit, stuckAtZero) {}
-	word64 GetCurrentTimerValue();
-	word64 TicksPerSecond();
+	TimerWord GetCurrentTimerValue();
+	TimerWord TicksPerSecond();
 };
 
-#endif
-
 NAMESPACE_END
 
 #endif
