@@ -1,7 +1,7 @@
 #ifndef CRYPTOPP_TIGER_H
 #define CRYPTOPP_TIGER_H
 
-#include "cryptopp_config.h"
+#include "config.h"
 
 #ifdef WORD64_AVAILABLE
 
@@ -9,17 +9,17 @@
 
 NAMESPACE_BEGIN(CryptoPP)
 
-/// <a href="http://www.weidai.com/scan-mirror/md.html#Tiger">Tiger</a>
+/// <a href="http://www.cryptolounge.org/wiki/Tiger">Tiger</a>
 class Tiger : public IteratedHashWithStaticTransform<word64, LittleEndian, 64, 24, Tiger>
 {
 public:
 	static void InitState(HashWordType *state);
 	static void Transform(word64 *digest, const word64 *data);
-	void TruncatedFinal(byte *hash, unsigned int size);
+	void TruncatedFinal(byte *hash, size_t size);
 	static const char * StaticAlgorithmName() {return "Tiger";}
 
 protected:
-	static const word64 table[4*256];
+	static const word64 table[4*256+3];
 };
 
 NAMESPACE_END
